==> zio-aws-finspacedata_3-5.17.144.1-sources.jar: zio/aws/finspacedata/model/DisableUserResponse.scala <==
package zio.aws.finspacedata.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.finspacedata.model.primitives.UserId
import scala.jdk.CollectionConverters.*
final case class DisableUserResponse(userId: Option[UserId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.finspacedata.model.DisableUserResponse = {
    import DisableUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
      .builder()
      .optionallyWith(
        userId.map(value => UserId.unwrap(value): java.lang.String)
      )(_.userId)
      .build()
  }
  def asReadOnly: zio.aws.finspacedata.model.DisableUserResponse.ReadOnly =
    zio.aws.finspacedata.model.DisableUserResponse.wrap(buildAwsValue())
}
object DisableUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.finspacedata.model.DisableUserResponse =
      zio.aws.finspacedata.model.DisableUserResponse(userId.map(value => value))
    def userId: Option[UserId]
    def getUserId: ZIO[Any, AwsError, UserId] =
      AwsError.unwrapOptionField("userId", userId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ) extends zio.aws.finspacedata.model.DisableUserResponse.ReadOnly {
    override val userId: Option[UserId] = scala
      .Option(impl.userId())
      .map(value => zio.aws.finspacedata.model.primitives.UserId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ): zio.aws.finspacedata.model.DisableUserResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-finspacedata_3-5.17.295.4-sources.jar: zio/aws/finspacedata/model/DisableUserResponse.scala <==
package zio.aws.finspacedata.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.finspacedata.model.primitives.UserId
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisableUserResponse(
    userId: Optional[UserId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.finspacedata.model.DisableUserResponse = {
    import DisableUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
      .builder()
      .optionallyWith(
        userId.map(value => UserId.unwrap(value): java.lang.String)
      )(_.userId)
      .build()
  }
  def asReadOnly: zio.aws.finspacedata.model.DisableUserResponse.ReadOnly =
    zio.aws.finspacedata.model.DisableUserResponse.wrap(buildAwsValue())
}
object DisableUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.finspacedata.model.DisableUserResponse =
      zio.aws.finspacedata.model.DisableUserResponse(userId.map(value => value))
    def userId: Optional[UserId]
    def getUserId: ZIO[Any, AwsError, UserId] =
      AwsError.unwrapOptionField("userId", userId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ) extends zio.aws.finspacedata.model.DisableUserResponse.ReadOnly {
    override val userId: Optional[UserId] = zio.aws.core.internal
      .optionalFromNullable(impl.userId())
      .map(value => zio.aws.finspacedata.model.primitives.UserId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.finspacedata.model.DisableUserResponse
  ): zio.aws.finspacedata.model.DisableUserResponse.ReadOnly = new Wrapper(impl)
}
